import { HttpContext } from '@objectiv/schema';
import { TrackerPluginInterface, TrackerValidationRuleInterface, TrackerInterface, ContextsConfig, TrackerEvent } from '@objectiv/tracker-core';

/**
 * The HttpContext Plugin gathers the current URL using the Location API.
 * It implements the `initialize` lifecycle method. This ensures the Context is generated when the tracker is created.
 */
declare class HttpContextPlugin implements TrackerPluginInterface {
    readonly pluginName = "HttpContextPlugin";
    validationRules: TrackerValidationRuleInterface[];
    initialized: boolean;
    httpContext?: HttpContext;
    /**
     * Generates an HttpContext and initializes validation rules.
     */
    initialize({ platform }: TrackerInterface): void;
    /**
     * Add the HttpContext to the Event's Global Contexts
     */
    enrich(contexts: Required<ContextsConfig>): void;
    /**
     * If the Plugin is usable runs all validation rules.
     */
    validate(event: TrackerEvent): void;
    /**
     * Make this plugin usable only on web, eg: Document and Navigation APIs are both available
     */
    isUsable(): boolean;
}

export { HttpContextPlugin };
